@@ -12,12 +12,8 @@
 #include <time.h>
 #include <qcolor.h>
 #include <qlabel.h>
-#include <qpushbutton.h>
-#include <qscrollbar.h>
 #include <qslider.h>
 #include <qlayout.h>
-#include <kapplication.h>
-#include <kbuttonbox.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kglobal.h>
@@ -32,21 +28,19 @@
 #define MAXLENGTH	65
 #define MAXVERTICES	19
 
-template class QMemArray<QPoint>;
-
 // libkscreensaver interface
 extern "C"
 {
-    const char *kss_applicationName = "kpolygon.kss";
-    const char *kss_description = I18N_NOOP( "KPolygon" );
-    const char *kss_version = "2.2.0";
+    KDE_EXPORT const char *kss_applicationName = "kpolygon.kss";
+    KDE_EXPORT const char *kss_description = I18N_NOOP( "KPolygon" );
+    KDE_EXPORT const char *kss_version = "2.2.0";
 
-    KScreenSaver *kss_create( WId id )
+    KDE_EXPORT KScreenSaver *kss_create( WId id )
     {
         return new kPolygonSaver( id );
     }
 
-    QDialog *kss_setup()
+    KDE_EXPORT QDialog *kss_setup()
     {
         return new kPolygonSetup();
     }
@@ -56,86 +50,59 @@ extern "C"
 // dialog to setup screen saver parameters
 //
 kPolygonSetup::kPolygonSetup( QWidget *parent, const char *name )
-	: QDialog( parent, name, TRUE )
+	: KDialogBase( parent, name, true, i18n( "Setup Polygon Screen Saver" ),
+	  Ok|Cancel|Help, Ok, true ), saver( 0 ), length( 10 ), vertices( 3 ),
+	  speed( 50 )
 {
-	saver = NULL;
-	length = 10;
-	vertices = 3;
-	speed = 50;
-
 	readSettings();
 
-	QString str;
-	QLabel *label;
-	QPushButton *button;
-	QSlider *sb;
+	QWidget *main = makeMainWidget();
+	setButtonText( Help, i18n( "A&bout" ) );
 
-	setCaption( i18n("Setup Polygon Screen Saver") );
-
-	QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
-	QHBoxLayout *tl1 = new QHBoxLayout;
+	QHBoxLayout *tl = new QHBoxLayout(main, 0, spacingHint());
+	QVBoxLayout *tl1 = new QVBoxLayout;
 	tl->addLayout(tl1);
-	QVBoxLayout *tl11 = new QVBoxLayout(5);
-	tl1->addLayout(tl11);	
 
-	label = new QLabel( i18n("Length:"), this );
-	tl11->addWidget(label);
+	QLabel *label = new QLabel( i18n("Length:"), main );
+	tl1->addWidget(label);
 
-	sb = new QSlider(1, MAXLENGTH, 10, length, QSlider::Horizontal, this );
+	QSlider *sb = new QSlider(1, MAXLENGTH, 10, length, QSlider::Horizontal,
+		main );
 	sb->setMinimumSize( 90, 20 );
     sb->setTickmarks(QSlider::Below);
     sb->setTickInterval(10);
-	connect( sb, SIGNAL( valueChanged( int ) ), 
-		 SLOT( slotLength( int ) ) );
-	tl11->addWidget(sb);
-	tl11->addSpacing(5);
+	connect( sb, SIGNAL( valueChanged( int ) ), SLOT( slotLength( int ) ) );
+	tl1->addWidget(sb);
 
-	label = new QLabel( i18n("Vertices:"), this );
-	tl11->addWidget(label);
+	label = new QLabel( i18n("Vertices:"), main );
+	tl1->addWidget(label);
 
-
-	sb = new QSlider(3, MAXVERTICES, 2, vertices, QSlider::Horizontal, this);
+	sb = new QSlider(3, MAXVERTICES, 2, vertices, QSlider::Horizontal, main);
 	sb->setMinimumSize( 90, 20 );
     sb->setTickmarks(QSlider::Below);
     sb->setTickInterval(2);
-	connect( sb, SIGNAL( valueChanged( int ) ), 
-		 SLOT( slotVertices( int ) ) );
-	tl11->addWidget(sb);
-	tl11->addSpacing(5);
+	connect( sb, SIGNAL( valueChanged( int ) ), SLOT( slotVertices( int ) ) );
+	tl1->addWidget(sb);
 
-	label = new QLabel( i18n("Speed:"), this );
-	tl11->addWidget(label);
+	label = new QLabel( i18n("Speed:"), main );
+	tl1->addWidget(label);
 
-	sb = new QSlider(0, 100, 10, speed, QSlider::Horizontal, this);
+	sb = new QSlider(0, 100, 10, speed, QSlider::Horizontal, main);
 	sb->setMinimumSize( 90, 20 );
     sb->setTickmarks(QSlider::Below);
     sb->setTickInterval(10);
-	connect( sb, SIGNAL( valueChanged( int ) ), 
-		 SLOT( slotSpeed( int ) ) );
-	tl11->addWidget(sb);
-	tl11->addStretch(1);
+	connect( sb, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
+	tl1->addWidget(sb);
+	tl1->addStretch();
 
-	preview = new QWidget( this );
+	preview = new QWidget( main );
 	preview->setFixedSize( 220, 170 );
 	preview->setBackgroundColor( black );
 	preview->show();    // otherwise saver does not get correct size
 	saver = new kPolygonSaver( preview->winId() );
-	tl1->addWidget(preview);
+	tl->addWidget(preview);
 
-	KButtonBox *bbox = new KButtonBox(this);	
-	button = bbox->addButton( i18n("&About"));
-	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
-	bbox->addStretch(1);
-
-	button = bbox->addButton( i18n("&OK"));	
-	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-	button = bbox->addButton(i18n("&Cancel"));
-	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-	bbox->layout();
-	tl->addWidget(bbox);
-
-	tl->freeze();
+	setMinimumSize( sizeHint() );
 }
 
 kPolygonSetup::~kPolygonSetup()
@@ -148,19 +115,19 @@ void kPolygonSetup::readSettings()
 {
     KConfig *config = KGlobal::config();
     config->setGroup( "Settings" );
-    
+
     length = config->readNumEntry( "Length", length );
     if ( length > MAXLENGTH )
         length = MAXLENGTH;
     else if ( length < 1 )
         length = 1;
-    
+
     vertices = config->readNumEntry( "Vertices", vertices );
     if ( vertices > MAXVERTICES )
         vertices = MAXVERTICES;
     else if ( vertices < 3 )
         vertices = 3;
-    
+
     speed = config->readNumEntry( "Speed", speed );
     if ( speed > 100 )
         speed = 100;
@@ -190,29 +157,29 @@ void kPolygonSetup::slotSpeed( int num )
 }
 
 // Ok pressed - save settings and exit
-void kPolygonSetup::slotOkPressed()
+void kPolygonSetup::slotOk()
 {
     KConfig *config = KGlobal::config();
     config->setGroup( "Settings" );
-    
+
     QString slength;
     slength.setNum( length );
     config->writeEntry( "Length", slength );
-    
+
     QString svertices;
     svertices.setNum( vertices );
     config->writeEntry( "Vertices", svertices );
-    
+
     QString sspeed;
     sspeed.setNum( speed );
     config->writeEntry( "Speed", sspeed );
-    
+
     config->sync();
-    
+
     accept();
 }
 
-void kPolygonSetup::slotAbout()
+void kPolygonSetup::slotHelp()
 {
 	KMessageBox::information(this,
 			     i18n("Polygon Version 2.2.0\n\n"\
