@@ -37,7 +37,7 @@ static const KCmdLineOptions options[] =
   KCmdLineLastOption
 };
 
-static void crashHandler( int sig )
+static void crashHandler( int /*sig*/ )
 {
 #ifdef SIGABRT
     signal ( SIGABRT, SIG_DFL );
@@ -49,7 +49,7 @@ static void crashHandler( int sig )
 
 int main(int argc, char *argv[])
 {
-    KCmdLineArgs::init(argc, argv, appName, description, version);
+    KCmdLineArgs::init(argc, argv, appName, I18N_NOOP("KLock"), description, version);
 
     KCmdLineArgs::addCmdLineOptions(options);
 
