@@ -5,7 +5,6 @@
 #include <qgroupbox.h>
 #include <qbuttongroup.h>
 #include <qlabel.h>
-#include <qslider.h>
 #include <qradiobutton.h>
 #include <qhbox.h>
 #include <kconfig.h>
@@ -14,7 +13,6 @@ class QCheckBox;
 class QGroupBox;
 class QVBox;
 class QLabel;
-class QSlider;
 class QRadioButton;
 
 class CdeConfig: public QObject
@@ -41,12 +39,10 @@ class CdeConfig: public QObject
 	private:
 		KConfig*   	cdeConfig;
 		QCheckBox* 	cbColorBorder;
-		QCheckBox* 	cbTitlebarButton;
-		QCheckBox* 	cbDeeperBevels;
+//		QCheckBox* 	cbTitlebarButton;
 		QHBox* 	        groupBox;
 		QGroupBox* 	gbSlider;
 		QButtonGroup*	bgAlign;
-		QSlider*   	widthSlider;
 };
 
 
